@@ -588,12 +588,9 @@ as.data.frame.dbi.table <- function(x, row.names = NULL, optional = FALSE, ...,
     j <- preprocess_j(substitute(j), x, parent, !is.null(by))
   }
 
-  sub_on <- substitute(on)
-  if (!is.null(sub_on)) {
-    on <- stry(eval(on, envir = parent))
-    if (inherits(on, "try-error")) {
-      on <- sub_on
-    }
+  on_sub <- substitute(on)
+  if (inherits(on <- stry(on), "try-error")) {
+    on <- on_sub
   }
 
   if (is.null(i) && is.null(j)) {
@@ -715,27 +712,26 @@ as.dbi.table <- function(conn, x, type = c("auto", "query", "temporary")) {
 
 
 
-temporary_dbi_table_name <- function(conn) {
-  UseMethod("temporary_dbi_table_name", dbi_connection(conn))
-}
-
-
-
-#' @rawNamespace S3method(temporary_dbi_table_name,default,temporary_dbi_table_name_default)
-temporary_dbi_table_name_default <- function(conn) {
-  unique_table_name(session$tmp_base)
-}
-
-
-
+#' @rawNamespace S3method(temporary_dbi_table,default,temporary_dbi_table_default)
 temporary_dbi_table <- function(conn, x, key = NULL) {
-  temp_name <- temporary_dbi_table_name(conn)
+  UseMethod("temporary_dbi_table", dbi_connection(conn))
+}
 
-  if (!DBI::dbWriteTable(conn, temp_name, x, temporary = TRUE)) {
+
+
+temporary_dbi_table_default <- function(conn, x, key = NULL) {
+  temp_name <- unique_table_name(session$tmp_base)
+  make_temp_dbi_table(conn, temp_name, x, key)
+}
+
+
+
+make_temp_dbi_table <- function(conn, name, x, key) {
+  if (!DBI::dbWriteTable(conn, name, x, temporary = TRUE)) {
     stop("could not create temporary table - permission denied")
   }
 
-  temp_id <- DBI::Id(temp_name)
+  temp_id <- DBI::Id(name)
   x <- new_dbi_table(conn, temp_id, names(x), key)
 
   temp_dbi_table <- new.env(parent = emptyenv())
